@@ -81,10 +81,10 @@ class ImageDetector:
               fnumbers = frames[i].split('.')[0]
               fnumbers = int(re.findall(r'[0-9]+', fnumbers)[0])
             except:
-                continue
+              fnumbers = i
             
             if not imgpath + '/' + frames[i]:
-                continue
+              continue
             
             frame = cv2.imread(imgpath + '/' + frames[i])
             frame = cv2.cvtColor(frame, cv2.COLOR_BGR2RGB)
